.. fastgpx documentation master file, created by
   sphinx-quickstart on Tue Apr 22 16:58:41 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

fastgpx documentation
=====================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   api
